@@ -1,5 +1,5 @@
 # rBiasCorrection: Correct Bias in Quantitative DNA Methylation Analyses.
-# Copyright (C) 2019-2020 Lorenz Kapsner
+# Copyright (C) 2019-2021 Lorenz Kapsner
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -120,12 +120,15 @@ calibration_plot <- function(plotlist,
     #%                     values = c(Cubic = "indianred1",
     #%                                Hyperbolic = "mediumspringgreen",
     #%                                unbiased = "lightblue")) +
-    ggpubr::theme_pubr() +
     ggplot2::theme(
       plot.title = ggplot2::element_text(hjust = 0.5),
       plot.subtitle = ggplot2::element_text(hjust = 0.5),
       text = ggplot2::element_text(size = plot_textsize)
     )
 
+  if ("ggpubr" %in% utils::installed.packages()[, "Package"]) {
+    outplot <- outplot + ggpubr::theme_pubr()
+  }
+
   return(outplot)
 }
